from eventlet import wsgi
from eventlet.greenio import GreenSocket

import eventlet
eventlet.monkey_patch()

# Принудительная инициализация сокетов
import eventlet.hubs
eventlet.hubs.use_hub()

# Явная проверка
import socket
print(f"Actual socket module: {socket.__name__}")
print(f"Actual socket class: {socket.socket}")

if not hasattr(socket, '_realsocket'):
    print("WARNING: Monkey patching failed!")
else:
    print("Monkey patching successful")

from flask_cors import CORS
from pymongo import MongoClient

from config import Config
from singletons.database_singleton import DatabaseSingleton

from infra.server import app, socketio
from controllers.user_controller import user_blueprint
from controllers.reservation_controller import reservation_blueprint
from controllers.health_controller import health_blueprint
from controllers.room_controller import room_blueprint

CORS(app)
app.config['JWT_SECRET_KEY'] = Config.JWT_SECRET_KEY

app.register_blueprint(user_blueprint, url_prefix='/user')
app.register_blueprint(reservation_blueprint, url_prefix='/reservation')
app.register_blueprint(room_blueprint, url_prefix='/room')
app.register_blueprint(health_blueprint, url_prefix='/health')

client = MongoClient(Config.MONGO_URI)
db = DatabaseSingleton.get_instance()

if db is not None:
    print('Connected to MongoDB')
else:
    print('Failed to connect to MongoDB')

def check_environment():
    import sys
    print("=== Environment Check ===")
    print(f"Python version: {sys.version}")
    print(f"Eventlet version: {eventlet.__version__}")
    print(f"GreenSocket available: {'eventlet.greenio.GreenSocket' in sys.modules}")
    print(f"Patched modules: {[m for m in sys.modules if m.startswith('__patched_module_')]}")
    print("========================")

check_environment()

if __name__ == '__main__':
    #app.run(debug=True)
    socketio.run(app, host=Config.APP_HOST, debug=False)
